from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id.delete import ApiFordelete
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id.patch import ApiForpatch


class DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass



# coding: utf-8

"""
    Versatile Data Kit Control Service API

    The Data Jobs API of Versatile Data Kit Control Service. Data Jobs allows Data Engineers to implement automated pull ingestion (E in ELT) and batch data transformation into a database (T in ELT). See also https://github.com/vmware/versatile-data-kit/wiki/Introduction The API has resource-oriented URLs, JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. The API enables creating, deploying, managing and executing Data Jobs in the runtime environment.<br> <br> ![](https://github.com/vmware/versatile-data-kit/wiki/vdk-data-job-lifecycle-state-diagram.png) <br> The API reflects the usual Data Job Development lifecycle:<br> <li> Create a new data job (webhook to further configure the job, e.g authorize its creation, setup permissions, etc). <li> Download keytab. Develop and run the data job locally. <li> Deploy the data job in cloud runtime environment to run on a scheduled basis. <br><br> If Authentication is enabled, pass OAuth2 access token in HTTP header 'Authorization: Bearer [access-token-here]' (https://datatracker.ietf.org/doc/html/rfc6750). <br The API promotes some best practices (inspired by https://12factor.net): <li> Explicitly declare and isolate dependencies. <li> Strict separation of configurations from code. Configurations vary substantially across deploys, code does not. <li> Separation between the build, release/deploy, and run stages. <li> Data Jobs are stateless and share-nothing processes. Any data that needs to be persisted must be stored in a stateful backing service (e.g IProperties). <li> Implementation is assumed to be atomic and idempotent - should be OK for a job to fail somewhere in the middle; subsequent restart should not cause data corruption. <li> Keep development, staging, and production as similar as possible. <br><br> <b>API Evolution</b><br> In the following sections, there are some terms that have a special meaning in the context of the APIs. <br><br> <li> <i>Stable</i> - The implementation of the API has been battle-tested (has been in production for some time). The API is a subject to semantic versioning model and will follow deprecation policy. <li> <i>Experimental</i> - May disappear without notice and is not a subject to semantic versioning. Implementation of the API is not considered stable nor well tested. Generally this is given to clients to experiment within testing environment. Must not be used in production. <li> <i>Deprecated</i> - API is expected to be removed within next one or two major version upgrade. The deprecation notice/comment will say when the API will be removed and what alternatives should be used instead.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""
import dataclasses
import typing

from urllib3._collections import HTTPHeaderDict


class OpenApiException(Exception):
    """The base exception class for all OpenAPIExceptions"""


class ApiTypeError(OpenApiException, TypeError):
    def __init__(self, msg, path_to_item=None, valid_classes=None,
                 key_type=None):
        """ Raises an exception for TypeErrors

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list): a list of keys an indices to get to the
                                 current_item
                                 None if unset
            valid_classes (tuple): the primitive classes that current item
                                   should be an instance of
                                   None if unset
            key_type (bool): False if our value is a value in a dict
                             True if it is a key in a dict
                             False if our item is an item in a list
                             None if unset
        """
        self.path_to_item = path_to_item
        self.valid_classes = valid_classes
        self.key_type = key_type
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiTypeError, self).__init__(full_msg)


class ApiValueError(OpenApiException, ValueError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (list) the path to the exception in the
                received_data dict. None if unset
        """

        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiValueError, self).__init__(full_msg)


class ApiAttributeError(OpenApiException, AttributeError):
    def __init__(self, msg, path_to_item=None):
        """
        Raised when an attribute reference or assignment fails.

        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiAttributeError, self).__init__(full_msg)


class ApiKeyError(OpenApiException, KeyError):
    def __init__(self, msg, path_to_item=None):
        """
        Args:
            msg (str): the exception message

        Keyword Args:
            path_to_item (None/list) the path to the exception in the
                received_data dict
        """
        self.path_to_item = path_to_item
        full_msg = msg
        if path_to_item:
            full_msg = "{0} at {1}".format(msg, render_path(path_to_item))
        super(ApiKeyError, self).__init__(full_msg)


T = typing.TypeVar("T")


@dataclasses.dataclass
class ApiException(OpenApiException, typing.Generic[T]):
    status: int
    reason: str
    api_response: typing.Optional[T] = None

    @property
    def body(self) -> typing.Union[str, bytes, None]:
        if not self.api_response:
            return None
        return self.api_response.response.data

    @property
    def headers(self) -> typing.Optional[HTTPHeaderDict]:
        if not self.api_response:
            return None
        return self.api_response.response.getheaders()

    def __str__(self):
        """Custom error messages for exception"""
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(
                self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message


def render_path(path_to_item):
    """Returns a string representation of a path"""
    result = ""
    for pth in path_to_item:
        if isinstance(pth, int):
            result += "[{0}]".format(pth)
        else:
            result += "['{0}']".format(pth)
    return result



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from taurus_datajob_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from taurus_datajob_api.model.data_job import DataJob
from taurus_datajob_api.model.data_job_api_info import DataJobApiInfo
from taurus_datajob_api.model.data_job_config import DataJobConfig
from taurus_datajob_api.model.data_job_contacts import DataJobContacts
from taurus_datajob_api.model.data_job_deployment import DataJobDeployment
from taurus_datajob_api.model.data_job_deployment_id import DataJobDeploymentId
from taurus_datajob_api.model.data_job_deployment_status import DataJobDeploymentStatus
from taurus_datajob_api.model.data_job_execution import DataJobExecution
from taurus_datajob_api.model.data_job_execution_logs import DataJobExecutionLogs
from taurus_datajob_api.model.data_job_execution_request import DataJobExecutionRequest
from taurus_datajob_api.model.data_job_mode import DataJobMode
from taurus_datajob_api.model.data_job_page import DataJobPage
from taurus_datajob_api.model.data_job_properties import DataJobProperties
from taurus_datajob_api.model.data_job_query_response import DataJobQueryResponse
from taurus_datajob_api.model.data_job_query_response_with_error import DataJobQueryResponseWithError
from taurus_datajob_api.model.data_job_resources import DataJobResources
from taurus_datajob_api.model.data_job_schedule import DataJobSchedule
from taurus_datajob_api.model.data_job_summary import DataJobSummary
from taurus_datajob_api.model.data_job_version import DataJobVersion
from taurus_datajob_api.model.error import Error



from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id.delete import ApiFordelete


class DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionId(
    ApiForget,
    ApiFordelete,
):
    pass



from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name.put import ApiForput
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name.delete import ApiFordelete


class DataJobsForTeamTeamNameJobsJobName(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    Versatile Data Kit Control Service API

    The Data Jobs API of Versatile Data Kit Control Service. Data Jobs allows Data Engineers to implement automated pull ingestion (E in ELT) and batch data transformation into a database (T in ELT). See also https://github.com/vmware/versatile-data-kit/wiki/Introduction The API has resource-oriented URLs, JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. The API enables creating, deploying, managing and executing Data Jobs in the runtime environment.<br> <br> ![](https://github.com/vmware/versatile-data-kit/wiki/vdk-data-job-lifecycle-state-diagram.png) <br> The API reflects the usual Data Job Development lifecycle:<br> <li> Create a new data job (webhook to further configure the job, e.g authorize its creation, setup permissions, etc). <li> Download keytab. Develop and run the data job locally. <li> Deploy the data job in cloud runtime environment to run on a scheduled basis. <br><br> If Authentication is enabled, pass OAuth2 access token in HTTP header 'Authorization: Bearer [access-token-here]' (https://datatracker.ietf.org/doc/html/rfc6750). <br The API promotes some best practices (inspired by https://12factor.net): <li> Explicitly declare and isolate dependencies. <li> Strict separation of configurations from code. Configurations vary substantially across deploys, code does not. <li> Separation between the build, release/deploy, and run stages. <li> Data Jobs are stateless and share-nothing processes. Any data that needs to be persisted must be stored in a stateful backing service (e.g IProperties). <li> Implementation is assumed to be atomic and idempotent - should be OK for a job to fail somewhere in the middle; subsequent restart should not cause data corruption. <li> Keep development, staging, and production as similar as possible. <br><br> <b>API Evolution</b><br> In the following sections, there are some terms that have a special meaning in the context of the APIs. <br><br> <li> <i>Stable</i> - The implementation of the API has been battle-tested (has been in production for some time). The API is a subject to semantic versioning model and will follow deprecation policy. <li> <i>Experimental</i> - May disappear without notice and is not a subject to semantic versioning. Implementation of the API is not considered stable nor well tested. Generally this is given to clients to experiment within testing environment. Must not be used in production. <li> <i>Deprecated</i> - API is expected to be removed within next one or two major version upgrade. The deprecation notice/comment will say when the API will be removed and what alternatives should be used instead.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from taurus_datajob_api import schemas  # noqa: F401


class DataJobExecutionRequest(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Request to start execution of Data Job. The job must have been deployed before that (see Deployment API) and will run its latest version.
    """


    class MetaOapg:
        
        class properties:
            started_by = schemas.StrSchema
            
            
            class args(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                ) -> 'args':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "started_by": started_by,
                "args": args,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["started_by"]) -> MetaOapg.properties.started_by: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["args"]) -> MetaOapg.properties.args: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["started_by", "args", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["started_by"]) -> typing.Union[MetaOapg.properties.started_by, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["args"]) -> typing.Union[MetaOapg.properties.args, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["started_by", "args", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        started_by: typing.Union[MetaOapg.properties.started_by, str, schemas.Unset] = schemas.unset,
        args: typing.Union[MetaOapg.properties.args, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'DataJobExecutionRequest':
        return super().__new__(
            cls,
            *_args,
            started_by=started_by,
            args=args,
            _configuration=_configuration,
            **kwargs,
        )



from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_sources.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_sources.post import ApiForpost
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_sources.delete import ApiFordelete


class DataJobsForTeamTeamNameJobsJobNameSources(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass



from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_executions.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_executions.post import ApiForpost


class DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdExecutions(
    ApiForget,
    ApiForpost,
):
    pass



from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_properties.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_properties.put import ApiForput


class DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdProperties(
    ApiForget,
    ApiForput,
):
    pass



from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs.post import ApiForpost


class DataJobsForTeamTeamNameJobs(
    ApiForget,
    ApiForpost,
):
    pass



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from taurus_datajob_api.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    DATAJOBS_FORTEAM_TEAM_NAME_INFO = "/data-jobs/for-team/{team_name}/info"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS = "/data-jobs/for-team/{team_name}/jobs"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME = "/data-jobs/for-team/{team_name}/jobs/{job_name}"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_KEYTAB = "/data-jobs/for-team/{team_name}/jobs/{job_name}/keytab"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_TEAM_NEW_TEAM = "/data-jobs/for-team/{team_name}/jobs/{job_name}/team/{new_team}"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS = "/data-jobs/for-team/{team_name}/jobs/{job_name}/deployments"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID = "/data-jobs/for-team/{team_name}/jobs/{job_name}/deployments/{deployment_id}"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS = "/data-jobs/for-team/{team_name}/jobs/{job_name}/executions"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID_EXECUTIONS = "/data-jobs/for-team/{team_name}/jobs/{job_name}/deployments/{deployment_id}/executions"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS_EXECUTION_ID = "/data-jobs/for-team/{team_name}/jobs/{job_name}/executions/{execution_id}"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS_EXECUTION_ID_LOGS = "/data-jobs/for-team/{team_name}/jobs/{job_name}/executions/{execution_id}/logs"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID_PROPERTIES = "/data-jobs/for-team/{team_name}/jobs/{job_name}/deployments/{deployment_id}/properties"
    DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_SOURCES = "/data-jobs/for-team/{team_name}/jobs/{job_name}/sources"



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

import unittest
from unittest.mock import patch

import urllib3

import taurus_datajob_api
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id import patch  # noqa: E501
from taurus_datajob_api import configuration, schemas, api_client

from .. import ApiTestMixin


class TestDataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId(ApiTestMixin, unittest.TestCase):
    """
    DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId unit test stubs
        Patch a deployment of a Data Job. Use it to change the configuration of a data job. For example: to enable or disable deployment, to change the vdk version. The operation is guranteed to be synchrounous so it cannot be used to deploy new version of a data job - job_version cannot be changed using PATCH. Use POST .../deployments for this. | (Stable)   # noqa: E501
    """
    _configuration = configuration.Configuration()

    def setUp(self):
        used_api_client = api_client.ApiClient(configuration=self._configuration)
        self.api = patch.ApiForpatch(api_client=used_api_client)  # noqa: E501

    def tearDown(self):
        pass

    response_status = 202
    response_body = ''




if __name__ == '__main__':
    unittest.main()



import typing_extensions

from taurus_datajob_api.apis.tags import TagValues
from taurus_datajob_api.apis.tags.data_jobs_api import DataJobsApi
from taurus_datajob_api.apis.tags.data_jobs_deployment_api import DataJobsDeploymentApi
from taurus_datajob_api.apis.tags.data_jobs_execution_api import DataJobsExecutionApi
from taurus_datajob_api.apis.tags.data_jobs_properties_api import DataJobsPropertiesApi
from taurus_datajob_api.apis.tags.data_jobs_service_api import DataJobsServiceApi
from taurus_datajob_api.apis.tags.data_jobs_sources_api import DataJobsSourcesApi

TagToApi = typing_extensions.TypedDict(
    'TagToApi',
    {
        TagValues.DATA_JOBS: DataJobsApi,
        TagValues.DATA_JOBS_DEPLOYMENT: DataJobsDeploymentApi,
        TagValues.DATA_JOBS_EXECUTION: DataJobsExecutionApi,
        TagValues.DATA_JOBS_PROPERTIES: DataJobsPropertiesApi,
        TagValues.DATA_JOBS_SERVICE: DataJobsServiceApi,
        TagValues.DATA_JOBS_SOURCES: DataJobsSourcesApi,
    }
)

tag_to_api = TagToApi(
    {
        TagValues.DATA_JOBS: DataJobsApi,
        TagValues.DATA_JOBS_DEPLOYMENT: DataJobsDeploymentApi,
        TagValues.DATA_JOBS_EXECUTION: DataJobsExecutionApi,
        TagValues.DATA_JOBS_PROPERTIES: DataJobsPropertiesApi,
        TagValues.DATA_JOBS_SERVICE: DataJobsServiceApi,
        TagValues.DATA_JOBS_SOURCES: DataJobsSourcesApi,
    }
)



# coding: utf-8

"""
    Versatile Data Kit Control Service API

    The Data Jobs API of Versatile Data Kit Control Service. Data Jobs allows Data Engineers to implement automated pull ingestion (E in ELT) and batch data transformation into a database (T in ELT). See also https://github.com/vmware/versatile-data-kit/wiki/Introduction The API has resource-oriented URLs, JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. The API enables creating, deploying, managing and executing Data Jobs in the runtime environment.<br> <br> ![](https://github.com/vmware/versatile-data-kit/wiki/vdk-data-job-lifecycle-state-diagram.png) <br> The API reflects the usual Data Job Development lifecycle:<br> <li> Create a new data job (webhook to further configure the job, e.g authorize its creation, setup permissions, etc). <li> Download keytab. Develop and run the data job locally. <li> Deploy the data job in cloud runtime environment to run on a scheduled basis. <br><br> If Authentication is enabled, pass OAuth2 access token in HTTP header 'Authorization: Bearer [access-token-here]' (https://datatracker.ietf.org/doc/html/rfc6750). <br The API promotes some best practices (inspired by https://12factor.net): <li> Explicitly declare and isolate dependencies. <li> Strict separation of configurations from code. Configurations vary substantially across deploys, code does not. <li> Separation between the build, release/deploy, and run stages. <li> Data Jobs are stateless and share-nothing processes. Any data that needs to be persisted must be stored in a stateful backing service (e.g IProperties). <li> Implementation is assumed to be atomic and idempotent - should be OK for a job to fail somewhere in the middle; subsequent restart should not cause data corruption. <li> Keep development, staging, and production as similar as possible. <br><br> <b>API Evolution</b><br> In the following sections, there are some terms that have a special meaning in the context of the APIs. <br><br> <li> <i>Stable</i> - The implementation of the API has been battle-tested (has been in production for some time). The API is a subject to semantic versioning model and will follow deprecation policy. <li> <i>Experimental</i> - May disappear without notice and is not a subject to semantic versioning. Implementation of the API is not considered stable nor well tested. Generally this is given to clients to experiment within testing environment. Must not be used in production. <li> <i>Deprecated</i> - API is expected to be removed within next one or two major version upgrade. The deprecation notice/comment will say when the API will be removed and what alternatives should be used instead.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

import logging
import ssl
from urllib.parse import urlencode
import typing

import certifi
import urllib3
from urllib3._collections import HTTPHeaderDict

from taurus_datajob_api.exceptions import ApiException, ApiValueError


logger = logging.getLogger(__name__)


class RESTClientObject(object):

    def __init__(self, configuration, pools_size=4, maxsize=None):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # maxsize is the number of requests to host that are allowed in parallel  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if configuration.ssl_ca_cert:
            ca_certs = configuration.ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        addition_pool_args = {}
        if configuration.assert_hostname is not None:
            addition_pool_args['assert_hostname'] = configuration.assert_hostname  # noqa: E501

        if configuration.retries is not None:
            addition_pool_args['retries'] = configuration.retries

        if configuration.socket_options is not None:
            addition_pool_args['socket_options'] = configuration.socket_options

        if maxsize is None:
            if configuration.connection_pool_maxsize is not None:
                maxsize = configuration.connection_pool_maxsize
            else:
                maxsize = 4

        # https pool manager
        if configuration.proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                proxy_url=configuration.proxy,
                proxy_headers=configuration.proxy_headers,
                **addition_pool_args
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=configuration.cert_file,
                key_file=configuration.key_file,
                **addition_pool_args
            )

    def request(
        self,
        method: str,
        url: str,
        headers: typing.Optional[HTTPHeaderDict] = None,
        fields: typing.Optional[typing.Tuple[typing.Tuple[str, typing.Any], ...]] = None,
        body: typing.Optional[typing.Union[str, bytes]] = None,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> urllib3.HTTPResponse:
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param headers: http request headers
        :param body: request body, for other types
        :param fields: request parameters for
                                `application/x-www-form-urlencoded`
                                or `multipart/form-data`
        :param stream: if True, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is False.
        :param timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT',
                          'PATCH', 'OPTIONS']

        if fields and body:
            raise ApiValueError(
                "body parameter cannot be used with fields parameter."
            )

        fields = fields or {}
        headers = headers or {}

        if timeout:
            if isinstance(timeout, (int, float)):  # noqa: E501,F821
                timeout = urllib3.Timeout(total=timeout)
            elif (isinstance(timeout, tuple) and
                  len(timeout) == 2):
                timeout = urllib3.Timeout(connect=timeout[0], read=timeout[1])

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if 'Content-Type' not in headers and body is None:
                    r = self.pool_manager.request(
                        method,
                        url,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers
                    )
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':  # noqa: E501
                    r = self.pool_manager.request(
                        method, url,
                        body=body,
                        fields=fields,
                        encode_multipart=False,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(
                        method, url,
                        fields=fields,
                        encode_multipart=True,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is
                # provided in serialized form
                elif isinstance(body, str) or isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(
                        method, url,
                        body=request_body,
                        preload_content=not stream,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              preload_content=not stream,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        if not stream:
            # log response body
            logger.debug("response body: %s", r.data)

        return r

    def GET(self, url, headers=None, stream=False,
            timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("GET", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def HEAD(self, url, headers=None, stream=False,
             timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("HEAD", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            fields=fields)

    def OPTIONS(self, url, headers=None,
                body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("OPTIONS", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def DELETE(self, url, headers=None, body=None,
               stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("DELETE", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def POST(self, url, headers=None,
             body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("POST", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PUT(self, url, headers=None,
            body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PUT", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)

    def PATCH(self, url, headers=None,
              body=None, stream=False, timeout=None, fields=None) -> urllib3.HTTPResponse:
        return self.request("PATCH", url,
                            headers=headers,
                            stream=stream,
                            timeout=timeout,
                            body=body, fields=fields)



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments import Api

from taurus_datajob_api.paths import PathValues

path = PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS


from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id_logs.get import ApiForget


class DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionIdLogs(
    ApiForget,
):
    pass



import typing_extensions

from taurus_datajob_api.paths import PathValues
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_info import DataJobsForTeamTeamNameInfo
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs import DataJobsForTeamTeamNameJobs
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name import DataJobsForTeamTeamNameJobsJobName
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_keytab import DataJobsForTeamTeamNameJobsJobNameKeytab
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_team_new_team import DataJobsForTeamTeamNameJobsJobNameTeamNewTeam
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_deployments import DataJobsForTeamTeamNameJobsJobNameDeployments
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id import DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_executions import DataJobsForTeamTeamNameJobsJobNameExecutions
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_executions import DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdExecutions
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id import DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionId
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id_logs import DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionIdLogs
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_properties import DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdProperties
from taurus_datajob_api.apis.paths.data_jobs_for_team_team_name_jobs_job_name_sources import DataJobsForTeamTeamNameJobsJobNameSources

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_INFO: DataJobsForTeamTeamNameInfo,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS: DataJobsForTeamTeamNameJobs,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME: DataJobsForTeamTeamNameJobsJobName,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_KEYTAB: DataJobsForTeamTeamNameJobsJobNameKeytab,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_TEAM_NEW_TEAM: DataJobsForTeamTeamNameJobsJobNameTeamNewTeam,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS: DataJobsForTeamTeamNameJobsJobNameDeployments,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID: DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS: DataJobsForTeamTeamNameJobsJobNameExecutions,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID_EXECUTIONS: DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdExecutions,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS_EXECUTION_ID: DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionId,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS_EXECUTION_ID_LOGS: DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionIdLogs,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID_PROPERTIES: DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdProperties,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_SOURCES: DataJobsForTeamTeamNameJobsJobNameSources,
    }
)

path_to_api = PathToApi(
    {
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_INFO: DataJobsForTeamTeamNameInfo,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS: DataJobsForTeamTeamNameJobs,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME: DataJobsForTeamTeamNameJobsJobName,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_KEYTAB: DataJobsForTeamTeamNameJobsJobNameKeytab,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_TEAM_NEW_TEAM: DataJobsForTeamTeamNameJobsJobNameTeamNewTeam,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS: DataJobsForTeamTeamNameJobsJobNameDeployments,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID: DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS: DataJobsForTeamTeamNameJobsJobNameExecutions,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID_EXECUTIONS: DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdExecutions,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS_EXECUTION_ID: DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionId,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_EXECUTIONS_EXECUTION_ID_LOGS: DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionIdLogs,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_DEPLOYMENTS_DEPLOYMENT_ID_PROPERTIES: DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdProperties,
        PathValues.DATAJOBS_FORTEAM_TEAM_NAME_JOBS_JOB_NAME_SOURCES: DataJobsForTeamTeamNameJobsJobNameSources,
    }
)



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from taurus_datajob_api.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    DATA_JOBS = "Data Jobs"
    DATA_JOBS_DEPLOYMENT = "Data Jobs Deployment"
    DATA_JOBS_EXECUTION = "Data Jobs Execution"
    DATA_JOBS_PROPERTIES = "Data Jobs Properties"
    DATA_JOBS_SERVICE = "Data Jobs Service"
    DATA_JOBS_SOURCES = "Data Jobs Sources"
